==> plsRglm_1.5.1.tar.gz: plsRglm/NEWS.md <==
# plsRglm 1.4.0

* Added functions for raw bootstrap. Added feature to support custom bootstrap function. 

# plsRglm 1.3.0

* Github actions and Roxygen most of the package.

# plsRglm 1.2.5

* Rewrote examples to cope with pkgdown requirements.

# plsRglm 1.2.4

* Improve examples in manual
* Bug fix in signpred if no variable was selected.
* Creating website for the package
* Github repository of the package is now public
* Added a `NEWS.md` file to track changes to the package.

# plsRglm 1.2.3

* Complete S3 methods to pass CRAN checks.

# plsRglm 1.2.2

* Sped up examples to pass CRAN checks.

# plsRglm 1.2.1

* Updated code to pass CRAN checks.

# plsRglm 1.2.0

* Added naive AIC and BIC output for data with missing values.

# plsRglm 1.1.1

* donttest update requested by CRAN.

# plsRglm 1.1.0

* Verbose option (request from Max Kuhn, caret package).

# plsRglm 1.0.1

* Fix for sPLS like option.

# plsRglm 1.0.0

* Major upgrade to enhance generics support. Package vignette (130 p.) release. Help of package completed.

# plsRglm 0.9.0

* Tilted bootstrap and demos fixed.

# plsRglm 0.8.3

* Code upgrade requested by R Core Team due to change in namespace policies.

# plsRglm 0.8.2

* Improvement of access to T-np or model based Bootstrap.

# plsRglm 0.8.1

* Graphical assessment of variable selection. Selection of bootstap techniques for CI plots.

# plsRglm 0.8.0

* Improved bootstrap stability.

# plsRglm 0.7.9

* polr demo fixed.

# plsRglm 0.7.8

*  Minor code enhancements.

# plsRglm 0.7.7

* Minor code enhancements.

# plsRglm 0.7.6

* Demos fixed.

# plsRglm 0.7.5

* Minor code enhancements.

# plsRglm 0.7.4

* Minor code enhancements.

# plsRglm 0.7.3

* Minor code fixes.

# plsRglm 0.7.2

* Cross-validation fully compatible with weighted plsR or plsRglm models.

# plsRglm 0.7.1

* Minor code changes.

# plsRglm 0.7.0

* Estimation of Degrees of Freedom for plsR models.

# plsRglm 0.6.7

* Weighted plsR models.

# plsRglm 0.6.5

* Sparse option to set to 0 the coefficients of non-significant predictors and to select the number of components.

# plsRglm 0.6.3

* Minor fixes to cope with upcoming changes in R 2.13. 

# plsRglm 0.6.2

* Support for logistic, probit, cloglog and cauchit links for cumulative link models.

# plsRglm 0.6.1

* Support for various glm or polr options.

# plsRglm 0.6.0

* Support for formulas.

# plsRglm 0.5.1

* Minor code changes.

# plsRglm 0.5.0

* Support for R or user defined "family" definition of glms added.

# plsRglm 0.4.0

* Support for Gamma(link = "inverse"), inverse.gaussian(link = "1/mu^2") and poisson(link = "log") added.

# plsRglm 0.3.4

* Minor code fixes.

# plsRglm 0.3.3

* Boostrap functionnalities improvement. Bootstrap no longer stops if model fitting fails for some subsample.

# plsRglm 0.2.0-0.3.2

* Support for polr, crossvalidations and bootstraps.

# plsRglm 0.1.2-0.1.5

* Creating help files.

==> plsRglm_1.6.0.tar.gz: plsRglm/NEWS.md <==
# plsRglm 1.6.0

* Maintainer email update.
* Added unit tests.
* Fix package to get rid of CRAN check notes

# plsRglm 1.5.1

Fix to methods as requested by CRAN and remove escaped latex characters.

# plsRglm 1.5.0

Fixes requested by CRAN.

# plsRglm 1.4.0

* Added functions for raw bootstrap. Added feature to support custom bootstrap function. 

# plsRglm 1.3.0

* Github actions and Roxygen most of the package.

# plsRglm 1.2.5

* Rewrote examples to cope with pkgdown requirements.

# plsRglm 1.2.4

* Improve examples in manual
* Bug fix in signpred if no variable was selected.
* Creating website for the package
* Github repository of the package is now public
* Added a `NEWS.md` file to track changes to the package.

# plsRglm 1.2.3

* Complete S3 methods to pass CRAN checks.

# plsRglm 1.2.2

* Sped up examples to pass CRAN checks.

# plsRglm 1.2.1

* Updated code to pass CRAN checks.

# plsRglm 1.2.0

* Added naive AIC and BIC output for data with missing values.

# plsRglm 1.1.1

* donttest update requested by CRAN.

# plsRglm 1.1.0

* Verbose option (request from Max Kuhn, caret package).

# plsRglm 1.0.1

* Fix for sPLS like option.

# plsRglm 1.0.0

* Major upgrade to enhance generics support. Package vignette (130 p.) release. Help of package completed.

# plsRglm 0.9.0

* Tilted bootstrap and demos fixed.

# plsRglm 0.8.3

* Code upgrade requested by R Core Team due to change in namespace policies.

# plsRglm 0.8.2

* Improvement of access to T-np or model based Bootstrap.

# plsRglm 0.8.1

* Graphical assessment of variable selection. Selection of bootstap techniques for CI plots.

# plsRglm 0.8.0

* Improved bootstrap stability.

# plsRglm 0.7.9

* polr demo fixed.

# plsRglm 0.7.8

*  Minor code enhancements.

# plsRglm 0.7.7

* Minor code enhancements.

# plsRglm 0.7.6

* Demos fixed.

# plsRglm 0.7.5

* Minor code enhancements.

# plsRglm 0.7.4

* Minor code enhancements.

# plsRglm 0.7.3

* Minor code fixes.

# plsRglm 0.7.2

* Cross-validation fully compatible with weighted plsR or plsRglm models.

# plsRglm 0.7.1

* Minor code changes.

# plsRglm 0.7.0

* Estimation of Degrees of Freedom for plsR models.

# plsRglm 0.6.7

* Weighted plsR models.

# plsRglm 0.6.5

* Sparse option to set to 0 the coefficients of non-significant predictors and to select the number of components.

# plsRglm 0.6.3

* Minor fixes to cope with upcoming changes in R 2.13. 

# plsRglm 0.6.2

* Support for logistic, probit, cloglog and cauchit links for cumulative link models.

# plsRglm 0.6.1

* Support for various glm or polr options.

# plsRglm 0.6.0

* Support for formulas.

# plsRglm 0.5.1

* Minor code changes.

# plsRglm 0.5.0

* Support for R or user defined "family" definition of glms added.

# plsRglm 0.4.0

* Support for Gamma(link = "inverse"), inverse.gaussian(link = "1/mu^2") and poisson(link = "log") added.

# plsRglm 0.3.4

* Minor code fixes.

# plsRglm 0.3.3

* Boostrap functionnalities improvement. Bootstrap no longer stops if model fitting fails for some subsample.

# plsRglm 0.2.0-0.3.2

* Support for polr, crossvalidations and bootstraps.

# plsRglm 0.1.2-0.1.5

* Creating help files.
